// IMPORTANT: Adafruit_TFTLCD LIBRARY MUST BE SPECIFICALLY
// CONFIGURED FOR EITHER THE TFT SHIELD OR THE BREAKOUT BOARD.
// SEE RELEVANT COMMENTS IN Adafruit_TFTLCD.h FOR SETUP.
#include <Wire.h>
#include <Adafruit_GFX.h>    // Core graphics library
#include <Adafruit_TFTLCD.h> // Hardware-specific library
//#include <PCM.h>

// The control pins for the LCD can be assigned to any digital or
// analog pins...but we'll use the analog pins as this allows us to
// double up the pins with the touch screen (see the TFT paint example).
#define LCD_CS A3 // Chip Select goes to Analog 3
#define LCD_CD A2 // Command/Data goes to Analog 2
#define LCD_WR A1 // LCD Write goes to Analog 1
#define LCD_RD A0 // LCD Read goes to Analog 0

#define LCD_RESET A4 // Can alternately just connect to Arduino's reset pin

int x = 0;
int y = 0;

// When using the BREAKOUT BOARD only, use these 8 data lines to the LCD:
// For the Arduino Uno, Duemilanove, Diecimila, etc.:
//   D0 connects to digital pin 8  (Notice these are
//   D1 connects to digital pin 9   NOT in order!)
//   D2 connects to digital pin 2
//   D3 connects to digital pin 3
//   D4 connects to digital pin 4
//   D5 connects to digital pin 5
//   D6 connects to digital pin 6
//   D7 connects to digital pin 7
// For the Arduino Mega, use digital pins 22 through 29
// (on the 2-row header at the end of the board).

// Assign human-readable names to some common 16-bit color values:
#define BLACK   0x0000
#define BLUE    0x001F
#define RED     0xF800
#define GREEN   0x07E0
#define CYAN    0x07FF
#define MAGENTA 0xF81F
#define YELLOW  0xFFE0
#define WHITE   0xFFFF

Adafruit_TFTLCD tft(LCD_CS, LCD_CD, LCD_WR, LCD_RD, LCD_RESET);
// If using the shield, all control and data lines are fixed, and
// a simpler declaration can optionally be used:
// Adafruit_TFTLCD tft;

void setup(void) {
  Wire.begin(2);
  
  Serial.begin(9600);
  Serial.println(F("TFT LCD test"));

#ifdef USE_ADAFRUIT_SHIELD_PINOUT
  Serial.println(F("Using Adafruit 2.8\" TFT Arduino Shield Pinout"));
#else
  Serial.println(F("Using Adafruit 2.8\" TFT Breakout Board Pinout"));
#endif

  Serial.print("TFT size is "); Serial.print(tft.width()); Serial.print("x"); Serial.println(tft.height());

  tft.reset();

  uint16_t identifier = tft.readID();

  if(identifier == 0x9325) {
    Serial.println(F("Found ILI9325 LCD driver"));
  } else if(identifier == 0x9328) {
    Serial.println(F("Found ILI9328 LCD driver"));
  } else if(identifier == 0x7575) {
    Serial.println(F("Found HX8347G LCD driver"));
  } else if(identifier == 0x9341) {
    Serial.println(F("Found ILI9341 LCD driver"));
  } else if(identifier == 0x8357) {
    Serial.println(F("Found HX8357D LCD driver"));
  } else {
    Serial.print(F("Unknown LCD driver chip: "));
    Serial.println(identifier, HEX);
    Serial.println(F("If using the Adafruit 2.8\" TFT Arduino shield, the line:"));
    Serial.println(F("  #define USE_ADAFRUIT_SHIELD_PINOUT"));
    Serial.println(F("should appear in the library header (Adafruit_TFT.h)."));
    Serial.println(F("If using the breakout board, it should NOT be #defined!"));
    Serial.println(F("Also if using the breakout, double-check that all wiring"));
    Serial.println(F("matches the tutorial."));
    return;
  }

  tft.begin(identifier);
  tft.fillScreen(BLACK);
}

void loop(void) {
  //for(uint8_t rotation=1; rotation<4; rotation=0) {
  tft.setRotation(1);
  testText();
  //delay(200000000);
  }

/*unsigned long testFillScreen() {
  unsigned long start = micros();
  tft.fillScreen(BLACK);
  tft.fillScreen(RED);
  tft.fillScreen(GREEN);
  tft.fillScreen(BLUE);
  tft.fillScreen(BLACK);
  return micros() - start;
}*/

unsigned long testText() {
  Wire.onReceive(receiveEvent);
  int HR = x;
  
  //tft.fillScreen(BLACK);      //USE THIS ONLY WHEN MAKING CHANGES TO THE OVERALL DESIGN OF THE DISPLAY
  tft.fillRect(60, 95, 145, 20, BLACK);         //refreshes current mood
  tft.fillRect(60, 195, 145, 20, BLACK);        //refreshes current BPM
  tft.fillRect(270, 95, 145, 20, BLACK);        //refreshes current speed
  tft.fillRect(310, 150, 70, 80, BLACK);        //refreshes heart

  
  unsigned long start = micros();
  tft.setCursor(15, 0);                       //tft.setCursor(x, y)
  tft.setTextColor(RED); tft.setTextSize(4);
  tft.println("Heart Racer Go-Kart");
  
  tft.setCursor(110, 80);
  tft.setTextColor(WHITE);   tft.setTextSize(2);
  tft.println("Mood");

  if(HR < 71 && HR > 0){                      //Current Mood with color
    tft.setCursor(103, 95);
    tft.setTextColor(WHITE);
    tft.println("Bored");
  }
  else if(HR > 70 && HR <91){
    tft.setCursor(93, 95);
    tft.setTextColor(MAGENTA);
    tft.println("Resting");
  }
  else if(HR > 90 && HR < 111){
    tft.setCursor(93, 95);
    tft.setTextColor(BLUE);
    tft.println("Relaxed");    
  }
  else if(HR > 110 && HR < 131){
    tft.setCursor(93, 95);
    tft.setTextColor(CYAN);
    tft.println("Excited");
  }
  else if(HR > 130 && HR < 151){
    tft.setCursor(75, 95);
    tft.setTextColor(GREEN);
    tft.println("Pumping Up");
  }
  else if (HR > 150 && HR < 171){
    tft.setCursor(93, 95);
    tft.setTextColor(YELLOW);
    tft.println("Boiling");
  }
  else if (HR > 171){
    tft.setCursor(65, 95);
    tft.setTextColor(RED);
    tft.println("Heart Attack");
  }
  
  tft.setCursor(275, 80);
  tft.setTextColor(WHITE);   tft.setTextSize(2);
  tft.println("Current MPH:");
  tft.setCursor(330, 95);
  tft.println(y);

  
  tft.setCursor(65, 180);
  tft.setTextColor(WHITE);   tft.setTextSize(2);
  tft.println("Current BPM:");

  tft.setCursor(120, 195);
  if(HR < 71 && HR > 0){                      //Current BPM number with color
    tft.setTextColor(WHITE);
    tft.println(HR);
  }
  else if(HR > 70 && HR <91){
    tft.setTextColor(MAGENTA);
    tft.println(HR);
  }
  else if(HR > 90 && HR < 111){    
    tft.setTextColor(BLUE);
    tft.println(HR);
  }
  else if(HR > 110 && HR < 131){    
    tft.setTextColor(CYAN);
    tft.println(HR);
  }
  else if(HR > 130 && HR < 151){    
    tft.setTextColor(GREEN);
    tft.println(HR);
  }
  else if (HR > 150 && HR < 171){    
    tft.setTextColor(YELLOW);
    tft.println(HR);
  }
  else if (HR > 171){    
    tft.setTextColor(RED);
    tft.println(HR);
  }
  
  tft.drawRect(50, 67, 165, 55, WHITE);                       //MOOD BOX     //tft.drawRect(x, y, width, height, color); 
  tft.drawRect(260, 67, 165, 55, WHITE);                      //CURRENT MPH BOX
  tft.drawRect(50, 167, 165, 55, WHITE);                      //CURRENT BPM BOX

  
  if(HR < 71 && HR > 0){                                      //Heart with color
    tft.fillTriangle(316, 180, 345, 220, 374, 180, WHITE);    //tft.fillTriangle(x1, y1, x2, y2, x3, y3, color);
    tft.fillCircle(330, 175, 15, WHITE);                      //tft.fillCircle(x, y, radius, color);
    tft.fillCircle(360, 175, 15, WHITE);
  }
  else if(HR > 70 && HR <91){
    tft.fillTriangle(316, 180, 345, 220, 374, 180, MAGENTA);    //tft.fillTriangle(x1, y1, x2, y2, x3, y3, color);
    tft.fillCircle(330, 175, 15, MAGENTA);                      //tft.fillCircle(x, y, radius, color);
    tft.fillCircle(360, 175, 15, MAGENTA);
  }
  else if(HR > 90 && HR < 111){    
    tft.fillTriangle(316, 180, 345, 220, 374, 180, BLUE);    //tft.fillTriangle(x1, y1, x2, y2, x3, y3, color);
    tft.fillCircle(330, 175, 15, BLUE);                      //tft.fillCircle(x, y, radius, color);
    tft.fillCircle(360, 175, 15, BLUE);
  }
  else if(HR > 110 && HR < 131){    
    tft.fillTriangle(316, 180, 345, 220, 374, 180, CYAN);    //tft.fillTriangle(x1, y1, x2, y2, x3, y3, color);
    tft.fillCircle(330, 175, 15, CYAN);                      //tft.fillCircle(x, y, radius, color);
    tft.fillCircle(360, 175, 15, CYAN);
  }
  else if(HR > 130 && HR < 151){    
   tft.fillTriangle(316, 180, 345, 220, 374, 180, GREEN);    //tft.fillTriangle(x1, y1, x2, y2, x3, y3, color);
    tft.fillCircle(330, 175, 15, GREEN);                      //tft.fillCircle(x, y, radius, color);
    tft.fillCircle(360, 175, 15, GREEN);
  }
  else if (HR > 150 && HR < 171){    
    tft.fillTriangle(316, 180, 345, 220, 374, 180, YELLOW);    //tft.fillTriangle(x1, y1, x2, y2, x3, y3, color);
    tft.fillCircle(330, 175, 15, YELLOW);                      //tft.fillCircle(x, y, radius, color);
    tft.fillCircle(360, 175, 15, YELLOW);
  }
  else if (HR > 171){    
    tft.fillTriangle(316, 180, 345, 220, 374, 180, RED);    //tft.fillTriangle(x1, y1, x2, y2, x3, y3, color);
    tft.fillCircle(330, 175, 15, RED);                      //tft.fillCircle(x, y, radius, color);
    tft.fillCircle(360, 175, 15, RED);
  }


  delay(5000);


  return micros() - start;
}

